#
# This class manages a syslog-ng server. It can be uses for standard logging or
# complex client/server setups
#
# === Parameters
#
# See README.md for a detailed parameter description
#
# === Variables
#
# No variables required. See params.pp for options.
#
# === Examples
#
# Basic setup:
#
#  import syslog_ng
#
# Some special logging
#
#  syslog_ng::destination::file {'d_file':
#    file => '/var/log/myapp.log'
#  }
#  syslog_ng::filter {'f_mypp':
#    spec => 'program(myapp_name)
#  }
#  syslog_ng::filter {'f_app_server':
#    spec => 'host(appserver.example.org)'
#  }
#  syslog_ng::log {'l_my_app':
#    source      => 's_src',
#    filter      => ['f_myapp', 'f_app_server'],
#    destination => 'd_file'
#  }
#
# === Authors
#
# Sören Berger <soeren.berger@u1337.de>
#
# === Copyright
#
# Copyright 2015 Sören Berger.
#

class syslog_ng (
  $system_log_dir            = $syslog_ng::params::system_log_dir,
  $config_dir                = $syslog_ng::params::config_dir,
  $local_source              = $syslog_ng::params::local_source,
  $reminder_file             = $syslog_ng::params::reminder_file,
  $create_dirs               = $syslog_ng::params::create_dirs,
  $default_owner             = $syslog_ng::params::default_owner,
  $default_group             = $syslog_ng::params::default_group,
  $default_perm              = $syslog_ng::params::default_perm,
  $use_fqdn                  = $syslog_ng::params::use_fqdn,
  $use_dns                   = $syslog_ng::params::use_dns,
  $chain_hostnames           = $syslog_ng::params::chain_hostnames,
  $keep_hostname             = $syslog_ng::params::keep_hostname,
  $stats_freq                = $syslog_ng::params::stats_freq,
  $mark_freq                 = $syslog_ng::params::mark_freq,
  $threaded                  = $syslog_ng::params::threaded,
  $flush_lines               = $syslog_ng::params::flush_lines,
  $include_tty10             = $syslog_ng::params::include_tty10,
  $log_fifo_size             = $syslog_ng::params::log_fifo_size,
  $log_fifo_size_destination = $syslog_ng::params::log_fifo_size_destination,
) inherits ::syslog_ng::params {
  $fragments = [
    $syslog_ng::params::config_file_sources,
    $syslog_ng::params::config_file_destination_files,
    $syslog_ng::params::config_file_destination_fallback,
    $syslog_ng::params::config_file_destination_remote,
    $syslog_ng::params::config_file_filter,
    $syslog_ng::params::config_file_parser,
    $syslog_ng::params::config_file_rewrite,
    $syslog_ng::params::config_file_blocks,
    $syslog_ng::params::config_file_logging,
    $syslog_ng::params::config_file_fallback,
  ]
  concat {$fragments:
    warn   => '#
# This file is generated by puppet. Do not edit
#
',
    notify => Service[syslog_ng],
    owner  => 'root',
    group  => 'root',
    mode   => '0644'
  }
  include syslog_ng::install
  include syslog_ng::service
}
